@@ -62,6 +62,7 @@ class DataMediator:
         if "holdoutProportion" in kwargs:
             self.holdoutProportion = kwargs["holdoutProportion"]
             del kwargs["holdoutProportion"]
+        self.balancingMethodCallback = None
         for flag, value in kwargs.items():
             # TODO: refactor using match case upon python 3.10 release
             # balance with given sampling method
@@ -71,7 +72,7 @@ class DataMediator:
                 self.filter(value)
             if flag == "verbose":
                 self.verbose = value
-            self.__balance(self.balancingMethodCallback)
+        self.__balance(self.balancingMethodCallback)
 
     @staticmethod
     def transposeDataFrame(
@@ -170,17 +171,20 @@ class DataMediator:
         # ignore chained assigment warning in Pandas since we are dropping rows in-place
         pd.options.mode.chained_assignment = None
         if balancingMethodCallback and self.balancingMethod == "downsampling":
-            dataToDrop = balancingMethodCallback(largeSplit)
+            dataToKeep = balancingMethodCallback(largeSplit)
             largeSplit.drop(
-                dataToDrop.index.symmetric_difference(largeSplit.index), inplace=True
+                dataToKeep.index.symmetric_difference(largeSplit.index), inplace=True
             )
         elif balancingMethodCallback and self.balancingMethod == "upsampling":
             dataToAdd = balancingMethodCallback(smallSplit)
             smallSplit.merge(dataToAdd)
         elif self.balancingMethod == "downsampling":
-            largeSplit = largeSplit.sample(
+            dataToKeep = largeSplit.sample(
                 len(smallSplit), random_state=self.randomSeed
             )
+            largeSplit.drop(
+                dataToKeep.index.symmetric_difference(largeSplit.index), inplace=True
+            )
         elif self.balancingMethod == "upsampling":
             dataToAdd = smallSplit.sample(
                 len(largeSplit), replace=True, random_state=self.randomSeed
@@ -223,7 +227,7 @@ class DataMediator:
             self.experimental = self.__experimental.copy(deep=True)
             self.control = self.__control.copy(deep=True)
         if self.balancingMethod:
-            self.__balance(self.balancingMethod, self.balancingMethodCallback)
+            self.__balance(self.balancingMethodCallback)
         self.trainTestSplit()
 
     def trainTestSplit(self, stratifyByClass=True) -> None:
